#!/usr/bin/env bash

appName=jsDesignAgent
appPath=/usr/local/bin/${appName}
serviceName=${appName}.service
servicePath=/lib/systemd/system/${serviceName}

# 用户未安装fontconfig，就提醒安装
echoErrMsg() {
cat << EOF
I require fontconfig but it's not installed.  Aborting!

Debian:
    apt-get install fontconfig
Ubuntu:
    apt-get install fontconfig
Alpine:
    apk add fontconfig
Arch Linux:
    pacman -S fontconfig
Kali Linux:
    apt-get install fontconfig
CentOS:
    yum install fontconfig
Fedora:
    dnf install fontconfig
Raspbian:
    apt-get install fontconfig
Docker:
    docker run cmd.cat/fc-list fc-list
EOF
exit 1
}

type fc-list >/dev/null 2>&1 || echoErrMsg

mkdir ${appPath}
cp ${appName} ${appPath}

cat>"${servicePath}"<<EOF
[Unit]
Description=jsDesignAgent for Access local fonts
After=network.target
StartLimitIntervalSec=0
[Service]
User=${USER}
Type=simple
Restart=always
RestartSec=1
ExecStart=${appPath}/${appName}

[Install]
WantedBy=multi-user.target
EOF

# 启动程序
systemctl start ${serviceName}

# 开机自启
systemctl enable ${serviceName}
